# -*- coding: utf-8 -*-
###############################################################################
#   Copyright (c) 2019 Eynes S.R.L (Leandro Martinek)
#   License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).
###############################################################################

import logging

from odoo import models, fields, api
# from odoo.exceptions import except_orm
# from odoo.addons.decimal_precision import decimal_precision as dp
# from odoo.tools import DEFAULT_SERVER_DATE_FORMAT, \
#         DEFAULT_SERVER_DATETIME_FORMAT, float_compare


_logger = logging.getLogger(__name__)


class ResDocumentType(models.Model):
    _inherit = 'res.document.type'

    @api.one
    def _set_default_check_dupl(self):
        self.check_duplicated = True


class Partner(models.Model):
    _name = "res.partner"
    _inherit = "res.partner"

    partner_type = fields.Selection(
        [('insurance', 'Insurance'),
        ('plan', 'Plan'),
        ('sofsa_user', 'Sofsa User')],
        string="Partner type",
        default=lambda x: x._get_default_partner_type())


    #Insurance fields
    health_insurance_plan_ids = fields.One2many(
        'health.insurance.plan',
        'insurance_id',
        string='Insurances')

    main_insurance_plan_id = fields.Many2one(
        'health.insurance.plan',
        'Main Insurance')
    can_import_roll = fields.Boolean(string='Can import roll?')
    requires_plan = fields.Boolean(string='Requires plan?')

    #Plan fields
    invoicing_type = fields.Selection(
        [('tax', 'Taxed'), ('no_tax', 'No Taxed'), ('na', 'N/A')],
        string='Invoicing Type', default='na')
    type = fields.Selection(
        selection_add=[('claim', 'Claim Address'), ('administrative', 'Administrative Address')])
    insurance_plan_id = fields.Many2one(
        'health.insurance.plan',
        string='Insurance plan',
        required=True,
        ondelete='cascade')


    @api.multi
    def _get_default_partner_type(self):
        return 'sofsa_user'

    @api.constrains('vat', 'document_type_id')
    def check_vat_duplicated(self):
        for partner in self:
            if partner.partner_type != 'plan':
                super(Partner, partner).check_vat_duplicated()

    @api.model
    def create(self, vals):
        res = super(Partner, self).create(vals)
        if not res.ref:
            if res.partner_type == 'insurance':
                res.ref = str(self.env['ir.sequence'].next_by_code('res.partner.insurance'))
        return res

    @api.multi
    def name_get(self):
        result = []
        for partner in self:
            if partner.partner_type == 'insurance':
                name = "[{}] {}".format(partner.ref, partner.name)
            else:
                name = partner.name
            result.append((partner.id, name))
        return result
