# -*- coding: utf-8 -*-
###############################################################################
#   Copyright (c) 2019 Eynes S.R.L (Santiago Said)
#   License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).
###############################################################################

import logging

from odoo import models, fields, api, _
from odoo.exceptions import ValidationError


_logger = logging.getLogger(__name__)


class HealthInsurancePlan(models.Model):
    _name = "health.insurance.plan"
    _description = "Health Insurance Plan"

    insurance_id = fields.Many2one(
        'res.partner',
        string='Health Insurance',
        required=True,
        domain='[("partner_type","=", "insurance")]',
        ondelete='restrict')
    partner_id = fields.Many2one(
        'res.partner',
        string='Partner',
        ondelete='restrict')
    active = fields.Boolean(default=True)
    name = fields.Char(string='Name', required=True)
    code = fields.Char(string='Code', required=True)
    observations = fields.Text(string='Observations')
    attention_point_ids = fields.One2many('health.attention.point','insurance_plan_id','Related attention points')

    @api.constrains('code', 'partner_id')
    def check_no_duplicated_ref(self):
        count = self.search_count([('code', '=', self.code), ('partner_id', '=', self.partner_id.id)])
        if count > 1:
            raise ValidationError(
                _('It already exists a health insurance plan of code %s and health insurance %s')
                % (_(self.code), _(self.partner_id.name)))

    @api.multi
    def get_partner_vals(self):
        vals = {
            'name': self.name,
            'ref': self.code,
            'insurance_plan_id': self.id,
            'partner_type': 'plan',
            'document_type_id': self.insurance_id.document_type_id.id if self.insurance_id.document_type_id else False,
            'vat': self.insurance_id.vat,
        }
        return vals

    @api.model
    def create(self, values):
        res = super(HealthInsurancePlan, self).create(values)
        partner = self.env['res.partner']
        pr = partner.create(res.get_partner_vals())
        res.partner_id = pr
        return res

    @api.multi
    def write(self, values):
        super(HealthInsurancePlan, self).write(values)
        for plan in self:
            plan.partner_id.write(plan.get_partner_vals())

